pub struct Contract {
pub market: Market,
/* private fields */
}Fields
market: MarketImplementations
Sourceimpl Contract
Internal helpers.
impl Contract
Internal helpers.
pub fn retrieve_price_pair(&self) -> Promise
pub fn price_pair(&self, oracle_response: OracleResponse) -> PricePair
pub fn execute_supply( &mut self, account_id: AccountId, amount: BorrowAssetAmount, )
pub fn execute_collateralize( &mut self, account_id: AccountId, amount: CollateralAssetAmount, price_pair: &PricePair, )
Sourcepub fn execute_repay(
&mut self,
account_id: AccountId,
amount: BorrowAssetAmount,
price_pair: &PricePair,
) -> BorrowAssetAmount
pub fn execute_repay( &mut self, account_id: AccountId, amount: BorrowAssetAmount, price_pair: &PricePair, ) -> BorrowAssetAmount
Returns the amount that should be returned to the account.
Sourceimpl Contract
External helpers.
impl Contract
External helpers.
pub const GAS_BORROW_01_CONSUME_PRICE: Gas
pub const GAS_BORROW_02_FINALIZE: Gas
pub const GAS_EXECUTE_NEXT_SUPPLY_WITHDRAWAL_REQUEST_01_FINALIZE: Gas
pub const GAS_COLLATERALIZE_TRANSFER_CALL_01_CONSUME_PRICE: Gas
pub const GAS_REPAY_TRANSFER_CALL_01_CONSUME_PRICE: Gas
pub const GAS_LIQUIDATE_TRANSFER_CALL_01_CONSUME_PRICE: Gas
pub const GAS_LIQUIDATE_TRANSFER_CALL_02_FINALIZE: Gas
pub const GAS_WITHDRAW_COLLATERAL_01_CONSUME_PRICE: Gas
pub const GAS_WITHDRAW_COLLATERAL_02_FINALIZE: Gas
pub const GAS_WITHDRAW_STATIC_YIELD_01_FINALIZE: Gas
pub fn borrow_01_consume_price( &mut self, account_id: AccountId, amount: BorrowAssetAmount, oracle_response: OracleResponse, ) -> Promise
pub fn borrow_02_finalize( &mut self, account_id: AccountId, initial_borrow: InitialBorrow, )
pub fn execute_next_supply_withdrawal_request_01_finalize( &mut self, resolutions: Vec<Withdrawal>, result: WithdrawalQueueExecutionResult, ) -> WithdrawalQueueExecutionResult
pub fn collateralize_transfer_call_01_consume_price( &mut self, account_id: AccountId, amount: CollateralAssetAmount, return_style: ReturnStyle, oracle_response: OracleResponse, ) -> Value
pub fn repay_transfer_call_01_consume_price( &mut self, account_id: AccountId, amount: BorrowAssetAmount, return_style: ReturnStyle, oracle_response: OracleResponse, ) -> Value
pub fn liquidate_transfer_call_01_consume_price( &mut self, liquidator_id: AccountId, amount: BorrowAssetAmount, msg: LiquidateMsg, return_style: ReturnStyle, oracle_response: OracleResponse, ) -> Promise
Sourcepub fn liquidate_transfer_call_02_finalize(
&mut self,
refund: BorrowAssetAmount,
return_style: ReturnStyle,
) -> Value
pub fn liquidate_transfer_call_02_finalize( &mut self, refund: BorrowAssetAmount, return_style: ReturnStyle, ) -> Value
Called during liquidation process; checks whether the transfer of collateral to the liquidator was successful.
pub fn withdraw_collateral_01_consume_price( &mut self, account_id: AccountId, amount: CollateralAssetAmount, oracle_response: OracleResponse, ) -> Promise
pub fn withdraw_collateral_02_finalize( &mut self, account_id: AccountId, amount: CollateralAssetAmount, )
pub fn withdraw_static_yield_01_finalize( &mut self, account_id: AccountId, amount: BorrowAssetAmount, )
Sourceimpl Contract
impl Contract
Sourcepub fn ext(account_id: AccountId) -> ContractExt
pub fn ext(account_id: AccountId) -> ContractExt
API for calling this contract’s functions in a subsequent execution.
pub fn ext_on(promise: Promise) -> ContractExt
Sourcepub fn ext_self() -> ContractExt
pub fn ext_self() -> ContractExt
Convenience method for creating a cross-contract call to the current contract.
Equivalent to Self::ext(near_sdk::env::current_account_id()).
Sourceimpl Contract
impl Contract
pub fn contract_source_metadata()
Methods from Deref<Target = Market>
pub fn borrowed(&self) -> FungibleAssetAmount<BorrowAsset>
pub fn total_incoming(&self) -> FungibleAssetAmount<BorrowAsset>
pub fn incoming_at( &self, snapshot_index: u32, ) -> FungibleAssetAmount<BorrowAsset>
pub fn get_last_finalized_snapshot(&self) -> &Snapshot
pub fn current_snapshot(&self) -> Snapshot
pub fn snapshot(&mut self) -> SnapshotProof
pub fn single_snapshot_fee( &self, amount: FungibleAssetAmount<BorrowAsset>, ) -> Option<FungibleAssetAmount<BorrowAsset>>
pub fn interest_rate(&self) -> Decimal
pub fn get_borrow_asset_available_to_borrow( &self, ) -> FungibleAssetAmount<BorrowAsset>
pub fn iter_supply_positions( &self, ) -> impl Iterator<Item = (AccountId, SupplyPosition)>
pub fn supply_position_ref( &self, account_id: AccountId, ) -> Option<SupplyPositionRef<&Market>>
pub fn supply_position_guard( &mut self, _proof: SnapshotProof, account_id: AccountId, ) -> Option<SupplyPositionGuard<'_>>
pub fn get_or_create_supply_position_guard( &mut self, _proof: SnapshotProof, account_id: AccountId, ) -> SupplyPositionGuard<'_>
pub fn cleanup_supply_position(&mut self, account_id: &AccountId) -> bool
pub fn iter_borrow_positions( &self, ) -> impl Iterator<Item = (AccountId, BorrowPosition)>
pub fn borrow_position_ref( &self, account_id: AccountId, ) -> Option<BorrowPositionRef<&Market>>
pub fn borrow_position_guard( &mut self, _proof: SnapshotProof, account_id: AccountId, ) -> Option<BorrowPositionGuard<'_>>
pub fn get_or_create_borrow_position_guard( &mut self, _proof: SnapshotProof, account_id: AccountId, ) -> BorrowPositionGuard<'_>
pub fn cleanup_borrow_position(&mut self, account_id: &AccountId) -> bool
pub fn record_borrow_asset_protocol_yield( &mut self, amount: FungibleAssetAmount<BorrowAsset>, )
pub fn record_borrow_asset_yield_distribution( &mut self, amount: FungibleAssetAmount<BorrowAsset>, )
pub fn accumulate_static_yield(
&mut self,
account_id: &AccountId,
snapshot_limit: u32,
) -> Result<(), UnknownAccount>
pub fn accumulate_static_yield( &mut self, account_id: &AccountId, snapshot_limit: u32, ) -> Result<(), UnknownAccount>
Accumulate static yield for an account.
Errors
- When the account is not configured to earn static yield.